@@ -11,13 +11,13 @@ try:
     from .cext import Proxy
     from .cext import identity
 except ImportError:
-    from .slots import Proxy
+    from .simple import Proxy
 else:
     copyreg.constructor(identity)
 
 try:
     from ._version import version as __version__
 except ImportError:
-    __version__ = '1.8.0'
+    __version__ = '1.9.0'
 
 __all__ = ("Proxy",)
